# pdm-manage-version

Wanted something like `poetry version` in `pdm`

## Alternatives

I found [https://github.com/abersheeran/pdm-version/](https://github.com/abersheeran/pdm-version/) but
it doesn't really behave like `poetry version` unfortunately
